// deployer DockerModule implementation
// Copyright (C) 2024 Jean-Cloud
// GNU General Public License v3

#include "DockerModule.h"
#include "BashManager.h"

//constructor and destructor inline 
DockerModule::DockerModule()
{
	name="Docker";
}
//public methods
int DockerModule::prepare()
{
	return BashManager::execute("systemctl start docker docker.socket");
}

int DockerModule::deploy (string serviceUsername)
{
	//go to the right directory
	//pulling images
	int pulling =BashManager::execute("docker-compose pull")==0;
	if(pulling==0){
		//starting service
		int starting=BashManager::execute("docker-compose up -d --remove-orphans"); 
	}else{
		cerr << "Error in DockerModule deploying "<< serviceUsername << endl;
		return -1;
	}
	return 0;
}

int removeContainersCreatedByDockerCompose()
{
	return BashManager::execute("docker-compose down --rmi all --remove-orphans");
}

int removeContainersWithServiceName(string serviceName)
{
	string dockerService=serviceName.replace(serviceName.find('.'),1,"_");
	string cmd="$(docker ps | grep " + dockerService +" | cut -d ' ' -f 1)";
	return BashManager::execute(cmd);
}

int DockerModule::remove (string serviceUsername)
{
	//remove unwanted containers
	removeContainersCreatedByDockerCompose();	
	removeContainersWithServiceName(serviceUsername);
	return 0;
}

int DockerModule::clean()
{
	return 0;
} 